@@ -1,6 +1,8 @@
+import aiofiles
 import logging
 import os
 import re
+from pathlib import Path
 
 from colorama import Fore, Style
 from yarl import URL
@@ -84,6 +86,12 @@ async def cyberdrop_parse(url: URL) -> URL:
     return URL(url)
 
 
+async def write_last_post_file(file: Path, url: str):
+    async with aiofiles.open(file, mode='a') as f:
+        await f.write(url + '\n')
+    return
+
+
 async def check_direct(url: URL):
     mapping_direct = ['i.pixl.is', r's..putmega.com', r's..putme.ga', r'img-...cyberdrop...', r'f.cyberdrop...',
                       r'fs-...cyberdrop...', r'cdn.bunkr...', r'cdn..bunkr...', r'media-files.bunkr...', r'jpg.church/images/...',
