@@ -34,6 +34,8 @@ class CyberdropCrawler:
             links = soup.select('div[class="image-container column"] a')
             for link in links:
                 link = URL(link.get('href'))
+                if 'cyberdrop' in link.host:
+                    link = URL('https://fs-01.cyberdrop.cc').with_name(link.name)
                 await domain_obj.add_to_album(title, link, url)
 
         except Exception as e:
