@@ -1,10 +1,12 @@
 import argparse
 import multiprocessing
+import platform
 from argparse import Namespace
 import asyncio
 import logging
+from asyncio.proactor_events import _ProactorBasePipeTransport
 from pathlib import Path
-import sys
+from functools import wraps
 
 from colorama import Fore
 from yarl import URL
@@ -35,9 +37,10 @@ def parse_args():
     parser.add_argument("--exclude-audio", help="skip downloading of audio files", action="store_true")
     parser.add_argument("--exclude-other", help="skip downloading of images", action="store_true")
     parser.add_argument("--ignore-history", help="This ignores previous download history", action="store_true")
+    parser.add_argument("--output-last-forum-post", help="Separates forum scraping into folders by post number", action="store_true")
     parser.add_argument("--separate-posts", help="Separates forum scraping into folders by post number", action="store_true")
-    parser.add_argument("--leakednudes-username", type=str, help="username to login to leakednudes", default=None)
-    parser.add_argument("--leakednudes-password", type=str, help="password to login to leakednudes", default=None)
+    parser.add_argument("--xbunker-username", type=str, help="username to login to xbunker", default=None)
+    parser.add_argument("--xbunker-password", type=str, help="password to login to xbunker", default=None)
     parser.add_argument("--socialmediagirls-username", type=str, help="username to login to socialmediagirls", default=None)
     parser.add_argument("--socialmediagirls-password", type=str, help="password to login to socialmediagirls", default=None)
     parser.add_argument("--simpcity-username", type=str, help="username to login to simpcity", default=None)
@@ -54,7 +57,7 @@ async def download_all(args: argparse.Namespace):
     await clear()
     await log(f"We are running version {VERSION} of Cyberdrop Downloader", Fore.WHITE)
     print_args = Namespace(**vars(args)).__dict__
-    print_args['leakednudes_password'] = '!REDACTED!'
+    print_args['xbunker_password'] = '!REDACTED!'
     print_args['socialmediagirls_password'] = '!REDACTED!'
     print_args['simpcity_password'] = '!REDACTED!'
     logging.debug(f"Starting downloader with args: {print_args}")
@@ -82,14 +85,22 @@ async def download_all(args: argparse.Namespace):
         await log("No links found, check the URL.txt\nIf the link works in your web browser, "
                   "please open an issue ticket with me.", Fore.RED)
 
-    leakednudes_auth = AuthData(args.leakednudes_username, args.leakednudes_password)
+    output_url_file = None
+
+    if args.output_last_forum_post:
+        output_url_file: Path = input_file.parent / "URLs_last_post.txt"
+        if output_url_file.exists():
+            output_url_file.unlink()
+            output_url_file.touch()
+
+    xbunker_auth = AuthData(args.xbunker_username, args.xbunker_password)
     socialmediagirls_auth = AuthData(args.socialmediagirls_username, args.socialmediagirls_password)
     simpcity_auth = AuthData(args.simpcity_username, args.simpcity_password)
     skip_data = SkipData(args.skip_hosts)
     excludes = {'videos': args.exclude_videos, 'images': args.exclude_images, 'audio': args.exclude_audio,
                 'other': args.exclude_other}
-    content_object = await scrape(links, client, args.include_id, leakednudes_auth, socialmediagirls_auth,
-                                  simpcity_auth, args.separate_posts, skip_data)
+    content_object = await scrape(links, client, args.include_id, xbunker_auth, socialmediagirls_auth,
+                                  simpcity_auth, args.separate_posts, skip_data, [args.output_last_forum_post, output_url_file])
 
     if await content_object.is_empty():
         logging.error('ValueError No links')
@@ -116,6 +127,17 @@ async def download_all(args: argparse.Namespace):
         await log('There are still partial downloads in your folders, please re-run the program.')
 
 
+def silence_event_loop_closed(func):
+    @wraps(func)
+    def wrapper(self, *args, **kwargs):
+        try:
+            return func(self, *args, **kwargs)
+        except RuntimeError as e:
+            if str(e) != 'Event loop is closed':
+                raise
+    return wrapper
+
+
 def main(args=None):
     if not args:
         args = parse_args()
@@ -126,6 +148,10 @@ def main(args=None):
         filemode="w"
     )
 
+    if platform.system() == 'Windows':
+        # Silence the "Event loop is closed" exception here.
+        _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(_ProactorBasePipeTransport.__del__)
+
     loop = asyncio.get_event_loop()
     loop.run_until_complete(download_all(args))
     loop.run_until_complete(asyncio.sleep(1))
